@@ -2,11 +2,12 @@ package it.unimi.dsi.fastutil.ints;
 
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
 import it.unimi.dsi.fastutil.Hash;
 import it.unimi.dsi.fastutil.HashCommon;
+import it.unimi.dsi.fastutil.objects.ObjectOpenHashSet;
 
 import java.io.IOException;
 import java.util.Arrays;
@@ -17,6 +18,47 @@ import org.junit.Test;
 @SuppressWarnings("rawtypes")
 public class IntOpenHashSetTest {
 
+	@SuppressWarnings("boxing")
+	@Test
+	public void testToArrayNullAtEnd() {
+		IntOpenHashSet s = new IntOpenHashSet( new int[] { 1, 2, 3 } );
+		assertEquals( 3, s.toArray( new Object[ 0 ] ).length );
+		assertEquals( 3, s.toArray( new Integer[ 0 ] ).length );
+		assertTrue( s.toArray( new Integer[] { -1, -1, -1, -1 } )[ 3 ] == null );
+	}
+
+	@Test
+	public void testContainsNull() {
+		IntOpenHashSet s = new IntOpenHashSet( new int[] { 1, 2, 3 } );
+		assertFalse( s.contains( null ) );
+	}
+
+	@SuppressWarnings("boxing")
+	@Test
+	public void testEquals() {
+		IntOpenHashSet s = new IntOpenHashSet( new int[] { 1, 2, 3 } );
+		assertFalse( s.equals( new ObjectOpenHashSet<Integer>( new Integer[] { 1, null } ) ) );
+	}
+
+	@Test
+	public void testInfiniteLoop0() {
+        IntOpenHashSet set = new IntOpenHashSet(4, 1.0f);
+        set.add(1);
+        set.add(2);
+        set.add(3);
+        set.remove(2);
+        set.trim();
+        set.remove(1); // Will hang inside this call
+    }
+
+	@Test
+	public void testInfiniteLoop1() {
+        IntOpenHashSet set = new IntOpenHashSet();
+        set.add(1);
+        set.add(2);
+        set.add(3);
+        set.trim(1);
+    }
 
 	@Test
 	public void testStrangeRetainAllCase() {
